@@ -14,3 +14,5 @@ from .ecg_rsp import ecg_rsp
 from .ecg_hrv import ecg_hrv
 from .ecg_phase import ecg_phase
 from .ecg_rsa import ecg_rsa
+from .ecg_intervalrelated import ecg_intervalrelated
+from .ecg_analyze import ecg_analyze
