@@ -7,7 +7,7 @@ from .signal_zerocrossings import signal_zerocrossings
 from .signal_smooth import signal_smooth
 from .signal_filter import signal_filter
 from .signal_psd import signal_psd
-from .signal_distord import signal_distord
+from .signal_distort import signal_distort
 from .signal_interpolate import signal_interpolate
 from .signal_detrend import signal_detrend
 from .signal_findpeaks import signal_findpeaks
