@@ -5,20 +5,21 @@ import matplotlib.pyplot as plt
 
 import biosppy
 
-np.random.seed(42)
-
 def test_rsp_simulate():
-    rsp1 = nk.rsp_simulate(duration=20, length=3000)
+    rsp1 = nk.rsp_simulate(duration=20, length=3000, random_state=42)
     assert len(rsp1) == 3000
 
-    rsp2 = nk.rsp_simulate(duration=20, length=3000, respiratory_rate=80)
+    rsp2 = nk.rsp_simulate(duration=20, length=3000, respiratory_rate=80,
+                           random_state=42)
 #    pd.DataFrame({"RSP1":rsp1, "RSP2":rsp2}).plot()
 #    pd.DataFrame({"RSP1":rsp1, "RSP2":rsp2}).hist()
     assert (len(nk.signal_findpeaks(rsp1, height_min=0.2)["Peaks"]) <
             len(nk.signal_findpeaks(rsp2, height_min=0.2)["Peaks"]))
 
-    rsp3 = nk.rsp_simulate(duration=20, length=3000, method="sinusoidal")
-    rsp4 = nk.rsp_simulate(duration=20, length=3000, method="breathmetrics")
+    rsp3 = nk.rsp_simulate(duration=20, length=3000, method="sinusoidal",
+                           random_state=42)
+    rsp4 = nk.rsp_simulate(duration=20, length=3000, method="breathmetrics",
+                           random_state=42)
 #    pd.DataFrame({"RSP3":rsp3, "RSP4":rsp4}).plot()
     assert (len(nk.signal_findpeaks(rsp3, height_min=0.2)["Peaks"]) >
             len(nk.signal_findpeaks(rsp4, height_min=0.2)["Peaks"]))
@@ -73,8 +74,8 @@ def test_rsp_peaks():
     assert signals["RSP_Troughs"].sum() == 28
     assert info["RSP_Peaks"].shape[0] == 28
     assert info["RSP_Troughs"].shape[0] == 28
-    assert np.allclose(info["RSP_Peaks"].sum(), 1643832)
-    assert np.allclose(info["RSP_Troughs"].sum(), 1586316)
+    assert np.allclose(info["RSP_Peaks"].sum(), 1643765)
+    assert np.allclose(info["RSP_Troughs"].sum(), 1586481)
     # Assert that extrema start with a trough and end with a peak.
     assert info["RSP_Peaks"][0] > info["RSP_Troughs"][0]
     assert info["RSP_Peaks"][-1] > info["RSP_Troughs"][-1]
@@ -182,3 +183,35 @@ def test_rsp_eventrelated():
                         "RSP_Amplitude_Mean", "RSP_Phase",
                         "RSP_PhaseCompletion", "Label"]
                for elem in np.array(rsp_eventrelated.columns.values, dtype=str))
+
+
+def test_rsp_rrv():
+
+    rsp90 = nk.rsp_simulate(duration=60, sampling_rate=1000, respiratory_rate=90, random_state=42)
+    rsp110 = nk.rsp_simulate(duration=60, sampling_rate=1000, respiratory_rate=110, random_state=42)
+
+    cleaned90 = nk.rsp_clean(rsp90, sampling_rate=1000)
+    _, peaks90 = nk.rsp_peaks(cleaned90)
+    rsp_rate90 = nk.rsp_rate(peaks90, desired_length=len(rsp90))
+
+    cleaned110 = nk.rsp_clean(rsp110, sampling_rate=1000)
+    _, peaks110 = nk.rsp_peaks(cleaned110)
+    rsp_rate110 = nk.rsp_rate(peaks110, desired_length=len(rsp110))
+
+    rsp90_rrv = nk.rsp_rrv(rsp_rate90, peaks90)
+    rsp110_rrv = nk.rsp_rrv(rsp_rate110, peaks110)
+
+    assert np.array(rsp90_rrv["RRV_SDBB"]) < np.array(rsp110_rrv["RRV_SDBB"])
+    assert np.array(rsp90_rrv["RRV_RMSSD"]) < np.array(rsp110_rrv["RRV_RMSSD"])
+    assert np.array(rsp90_rrv["RRV_SDSD"]) < np.array(rsp110_rrv["RRV_SDSD"])
+    # assert np.array(rsp90_rrv["RRV_pNN50"]) == np.array(rsp110_rrv["RRV_pNN50"]) == np.array(rsp110_rrv["RRV_pNN20"]) == np.array(rsp90_rrv["RRV_pNN20"]) == 0
+    # assert np.array(rsp90_rrv["RRV_TINN"]) < np.array(rsp110_rrv["RRV_TINN"])
+    # assert np.array(rsp90_rrv["RRV_HTI"]) > np.array(rsp110_rrv["RRV_HTI"])
+    assert np.array(rsp90_rrv["RRV_HF"]) < np.array(rsp110_rrv["RRV_HF"])
+    assert np.array(rsp90_rrv["RRV_LF"]) < np.array(rsp110_rrv["RRV_LF"])
+
+#    assert all(elem in ['RRV_SDBB','RRV_RMSSD', 'RRV_SDSD'
+#                        'RRV_VLF', 'RRV_LF', 'RRV_HF', 'RRV_LFHF',
+#                        'RRV_LFn', 'RRV_HFn',
+#                        'RRV_SD1', 'RRV_SD2', 'RRV_SD2SD1','RRV_ApEn', 'RRV_SampEn', 'RRV_DFA']
+#               for elem in np.array(rsp110_rrv.columns.values, dtype=str))
